==> qore-0.8.10.tar.bz2: qore-0.8.10/docs/library/html/search/variables_71.js <==
var searchData=
[
  ['qcs_5fdefault',['QCS_DEFAULT',['../_qore_encoding_8h.html#a4308cc04e6fb8c20cc9f959f589142a7',1,'QoreEncoding.h']]],
  ['qcs_5fiso_5f8859_5f1',['QCS_ISO_8859_1',['../_qore_encoding_8h.html#a93171772093d63ad75c467fe0c2c7043',1,'QoreEncoding.h']]],
  ['qcs_5fiso_5f8859_5f10',['QCS_ISO_8859_10',['../_qore_encoding_8h.html#a90ad73f30aa480e2d3667f926dfcf4ff',1,'QoreEncoding.h']]],
  ['qcs_5fiso_5f8859_5f11',['QCS_ISO_8859_11',['../_qore_encoding_8h.html#a2031e2911dbfa0fc1e13f9d72991a54d',1,'QoreEncoding.h']]],
  ['qcs_5fiso_5f8859_5f13',['QCS_ISO_8859_13',['../_qore_encoding_8h.html#af5041662adf60824e600b2bf435cf8cd',1,'QoreEncoding.h']]],
  ['qcs_5fiso_5f8859_5f14',['QCS_ISO_8859_14',['../_qore_encoding_8h.html#af15e4b3c56e1edd6536c82fa6156c020',1,'QoreEncoding.h']]],
  ['qcs_5fiso_5f8859_5f15',['QCS_ISO_8859_15',['../_qore_encoding_8h.html#a52117c9a489cd04d5a8ffa534ddd6d56',1,'QoreEncoding.h']]],
  ['qcs_5fiso_5f8859_5f16',['QCS_ISO_8859_16',['../_qore_encoding_8h.html#a74222d844254b08e105686782ef79e37',1,'QoreEncoding.h']]],
  ['qcs_5fiso_5f8859_5f2',['QCS_ISO_8859_2',['../_qore_encoding_8h.html#a8aaa560727e623727bd4bc70b93f29ba',1,'QoreEncoding.h']]],
  ['qcs_5fiso_5f8859_5f3',['QCS_ISO_8859_3',['../_qore_encoding_8h.html#abc7f7c11d6c428106ec1644340ddb4a9',1,'QoreEncoding.h']]],
  ['qcs_5fiso_5f8859_5f4',['QCS_ISO_8859_4',['../_qore_encoding_8h.html#a1d67a88a2ca193888344d3486a3ec83e',1,'QoreEncoding.h']]],
  ['qcs_5fiso_5f8859_5f5',['QCS_ISO_8859_5',['../_qore_encoding_8h.html#aa62ed6d785b4b0a23546eb1a1efe96d0',1,'QoreEncoding.h']]],
  ['qcs_5fiso_5f8859_5f6',['QCS_ISO_8859_6',['../_qore_encoding_8h.html#a5b8bc561ea2f472495e69c864a009b99',1,'QoreEncoding.h']]],
  ['qcs_5fiso_5f8859_5f7',['QCS_ISO_8859_7',['../_qore_encoding_8h.html#a71b4c748084cdf08a5f4521a6edfafae',1,'QoreEncoding.h']]],
  ['qcs_5fiso_5f8859_5f8',['QCS_ISO_8859_8',['../_qore_encoding_8h.html#a5e304c75cbc82ad4ac129c30398da060',1,'QoreEncoding.h']]],
  ['qcs_5fiso_5f8859_5f9',['QCS_ISO_8859_9',['../_qore_encoding_8h.html#a638469d81cb3c7b31e021275eb741bd3',1,'QoreEncoding.h']]],
  ['qcs_5fkoi7',['QCS_KOI7',['../_qore_encoding_8h.html#a0a2187dcb6066bab5b6e9b7437e14988',1,'QoreEncoding.h']]],
  ['qcs_5fkoi8_5fr',['QCS_KOI8_R',['../_qore_encoding_8h.html#a165d07206dc3861e1cb365ff8f668c0d',1,'QoreEncoding.h']]],
  ['qcs_5fkoi8_5fu',['QCS_KOI8_U',['../_qore_encoding_8h.html#a1820969632205d2977e9852a82923757',1,'QoreEncoding.h']]],
  ['qcs_5fusascii',['QCS_USASCII',['../_qore_encoding_8h.html#aced67d63d1f7a096d1dcfa001fb5899c',1,'QoreEncoding.h']]],
  ['qcs_5futf8',['QCS_UTF8',['../_qore_encoding_8h.html#a880cbaace0e6c6bd6e505c127ce17fe0',1,'QoreEncoding.h']]],
  ['qem',['QEM',['../_qore_encoding_8h.html#ab940a74ecff665f34d96e127e621cf7c',1,'QoreEncoding.h']]],
  ['qore_5fbuild_5fhost',['qore_build_host',['../_qore_8h.html#a355fb78ea8b9668ca413a9a802e3cdea',1,'Qore.h']]],
  ['qore_5fbuild_5fnumber',['qore_build_number',['../_qore_8h.html#a450bf7869a253a12612af9c6a564193c',1,'Qore.h']]],
  ['qore_5fcflags',['qore_cflags',['../_qore_8h.html#a85aa68ae2c985289d7426f857e0cab94',1,'Qore.h']]],
  ['qore_5fcplusplus_5fcompiler',['qore_cplusplus_compiler',['../_qore_8h.html#a889d0fef9a14c3b8af010f54899cf2e7',1,'Qore.h']]],
  ['qore_5fldflags',['qore_ldflags',['../_qore_8h.html#a508f7115ca9b7afd39e717c0a924236f',1,'Qore.h']]],
  ['qore_5fmin_5fmod_5fapi_5fmajor',['qore_min_mod_api_major',['../_qore_8h.html#ac8b0b4d105761a37356f160dc43d469a',1,'Qore.h']]],
  ['qore_5fmin_5fmod_5fapi_5fminor',['qore_min_mod_api_minor',['../_qore_8h.html#a8bf796ea5454be80c9eec2e8cfc73a15',1,'Qore.h']]],
  ['qore_5fmod_5fapi_5flist',['qore_mod_api_list',['../_module_manager_8h.html#ad50f255e8fa1555f632d314795c18ed0',1,'ModuleManager.h']]],
  ['qore_5fmod_5fapi_5flist_5flen',['qore_mod_api_list_len',['../_module_manager_8h.html#a741e33a9d4fa1c859221d28b7d08a614',1,'ModuleManager.h']]],
  ['qore_5fmodule_5fdir',['qore_module_dir',['../_qore_8h.html#ae2a979e14a7dc2fe6d90145af605b13b',1,'Qore.h']]],
  ['qore_5fmpfr_5finfo',['qore_mpfr_info',['../_qore_8h.html#ae605151efb26ed182db3e3ba17f7589e',1,'Qore.h']]],
  ['qore_5foption_5flist',['qore_option_list',['../_qore_lib_8h.html#a5cde9811a961ae6a74c0cd73475e57c4',1,'QoreLib.h']]],
  ['qore_5foption_5flist_5fsize',['qore_option_list_size',['../_qore_lib_8h.html#aa60708e218d814c21748ceea4cacf988',1,'QoreLib.h']]],
  ['qore_5ftarget_5farch',['qore_target_arch',['../_qore_8h.html#a5546e4dae74dad8cc82e5df8fad0b2ad',1,'Qore.h']]],
  ['qore_5ftarget_5fbits',['qore_target_bits',['../_qore_8h.html#a07892319abacd76008bc08af779fbd26',1,'Qore.h']]],
  ['qore_5ftarget_5fos',['qore_target_os',['../_qore_8h.html#a21698698cda36328f1e41b348c8cf369',1,'Qore.h']]],
  ['qore_5fversion_5fmajor',['qore_version_major',['../_qore_8h.html#a52951fca864ecf13261713a95415a778',1,'Qore.h']]],
  ['qore_5fversion_5fminor',['qore_version_minor',['../_qore_8h.html#ae94a08dda726f7123de466ef8554feaa',1,'Qore.h']]],
  ['qore_5fversion_5fstring',['qore_version_string',['../_qore_8h.html#a8c83964eb36898516fa586eee168ec2d',1,'Qore.h']]],
  ['qore_5fversion_5fsub',['qore_version_sub',['../_qore_8h.html#acae8385e006320c7cea8b1ff11821440',1,'Qore.h']]],
  ['qorefeaturelist',['qoreFeatureList',['../_qore_lib_8h.html#a84f94f41c2e05181094a4d4b95359157',1,'QoreLib.h']]]
];

==> qore-0.8.12.2.tar.bz2: qore-0.8.12.2/docs/library/html/search/variables_71.js <==
var searchData=
[
  ['qcs_5fdefault',['QCS_DEFAULT',['../_qore_encoding_8h.html#a4308cc04e6fb8c20cc9f959f589142a7',1,'QoreEncoding.h']]],
  ['qcs_5fiso_5f8859_5f1',['QCS_ISO_8859_1',['../_qore_encoding_8h.html#a93171772093d63ad75c467fe0c2c7043',1,'QoreEncoding.h']]],
  ['qcs_5fiso_5f8859_5f10',['QCS_ISO_8859_10',['../_qore_encoding_8h.html#a90ad73f30aa480e2d3667f926dfcf4ff',1,'QoreEncoding.h']]],
  ['qcs_5fiso_5f8859_5f11',['QCS_ISO_8859_11',['../_qore_encoding_8h.html#a2031e2911dbfa0fc1e13f9d72991a54d',1,'QoreEncoding.h']]],
  ['qcs_5fiso_5f8859_5f13',['QCS_ISO_8859_13',['../_qore_encoding_8h.html#af5041662adf60824e600b2bf435cf8cd',1,'QoreEncoding.h']]],
  ['qcs_5fiso_5f8859_5f14',['QCS_ISO_8859_14',['../_qore_encoding_8h.html#af15e4b3c56e1edd6536c82fa6156c020',1,'QoreEncoding.h']]],
  ['qcs_5fiso_5f8859_5f15',['QCS_ISO_8859_15',['../_qore_encoding_8h.html#a52117c9a489cd04d5a8ffa534ddd6d56',1,'QoreEncoding.h']]],
  ['qcs_5fiso_5f8859_5f16',['QCS_ISO_8859_16',['../_qore_encoding_8h.html#a74222d844254b08e105686782ef79e37',1,'QoreEncoding.h']]],
  ['qcs_5fiso_5f8859_5f2',['QCS_ISO_8859_2',['../_qore_encoding_8h.html#a8aaa560727e623727bd4bc70b93f29ba',1,'QoreEncoding.h']]],
  ['qcs_5fiso_5f8859_5f3',['QCS_ISO_8859_3',['../_qore_encoding_8h.html#abc7f7c11d6c428106ec1644340ddb4a9',1,'QoreEncoding.h']]],
  ['qcs_5fiso_5f8859_5f4',['QCS_ISO_8859_4',['../_qore_encoding_8h.html#a1d67a88a2ca193888344d3486a3ec83e',1,'QoreEncoding.h']]],
  ['qcs_5fiso_5f8859_5f5',['QCS_ISO_8859_5',['../_qore_encoding_8h.html#aa62ed6d785b4b0a23546eb1a1efe96d0',1,'QoreEncoding.h']]],
  ['qcs_5fiso_5f8859_5f6',['QCS_ISO_8859_6',['../_qore_encoding_8h.html#a5b8bc561ea2f472495e69c864a009b99',1,'QoreEncoding.h']]],
  ['qcs_5fiso_5f8859_5f7',['QCS_ISO_8859_7',['../_qore_encoding_8h.html#a71b4c748084cdf08a5f4521a6edfafae',1,'QoreEncoding.h']]],
  ['qcs_5fiso_5f8859_5f8',['QCS_ISO_8859_8',['../_qore_encoding_8h.html#a5e304c75cbc82ad4ac129c30398da060',1,'QoreEncoding.h']]],
  ['qcs_5fiso_5f8859_5f9',['QCS_ISO_8859_9',['../_qore_encoding_8h.html#a638469d81cb3c7b31e021275eb741bd3',1,'QoreEncoding.h']]],
  ['qcs_5fkoi7',['QCS_KOI7',['../_qore_encoding_8h.html#a0a2187dcb6066bab5b6e9b7437e14988',1,'QoreEncoding.h']]],
  ['qcs_5fkoi8_5fr',['QCS_KOI8_R',['../_qore_encoding_8h.html#a165d07206dc3861e1cb365ff8f668c0d',1,'QoreEncoding.h']]],
  ['qcs_5fkoi8_5fu',['QCS_KOI8_U',['../_qore_encoding_8h.html#a1820969632205d2977e9852a82923757',1,'QoreEncoding.h']]],
  ['qcs_5fusascii',['QCS_USASCII',['../_qore_encoding_8h.html#aced67d63d1f7a096d1dcfa001fb5899c',1,'QoreEncoding.h']]],
  ['qcs_5futf16',['QCS_UTF16',['../_qore_encoding_8h.html#a0012c6d9eea6cb8e3cd8e889f1e154d6',1,'QoreEncoding.h']]],
  ['qcs_5futf16be',['QCS_UTF16BE',['../_qore_encoding_8h.html#a604c1b804966f1a3b24b8044e5d7871f',1,'QoreEncoding.h']]],
  ['qcs_5futf16le',['QCS_UTF16LE',['../_qore_encoding_8h.html#a52b7cd3eeca6bc638359e39614d6ae44',1,'QoreEncoding.h']]],
  ['qcs_5futf8',['QCS_UTF8',['../_qore_encoding_8h.html#a880cbaace0e6c6bd6e505c127ce17fe0',1,'QoreEncoding.h']]],
  ['qem',['QEM',['../_qore_encoding_8h.html#ab940a74ecff665f34d96e127e621cf7c',1,'QoreEncoding.h']]],
  ['qore_5fbuild_5fhost',['qore_build_host',['../_qore_8h.html#a355fb78ea8b9668ca413a9a802e3cdea',1,'Qore.h']]],
  ['qore_5fbuild_5fnumber',['qore_build_number',['../_qore_8h.html#a450bf7869a253a12612af9c6a564193c',1,'Qore.h']]],
  ['qore_5fcflags',['qore_cflags',['../_qore_8h.html#a85aa68ae2c985289d7426f857e0cab94',1,'Qore.h']]],
  ['qore_5fcplusplus_5fcompiler',['qore_cplusplus_compiler',['../_qore_8h.html#a889d0fef9a14c3b8af010f54899cf2e7',1,'Qore.h']]],
  ['qore_5fgit_5fhash',['qore_git_hash',['../_qore_8h.html#a198a26bd1ba837a03fe2d0c79a3e0700',1,'Qore.h']]],
  ['qore_5fldflags',['qore_ldflags',['../_qore_8h.html#a508f7115ca9b7afd39e717c0a924236f',1,'Qore.h']]],
  ['qore_5fmin_5fmod_5fapi_5fmajor',['qore_min_mod_api_major',['../_qore_8h.html#ac8b0b4d105761a37356f160dc43d469a',1,'Qore.h']]],
  ['qore_5fmin_5fmod_5fapi_5fminor',['qore_min_mod_api_minor',['../_qore_8h.html#a8bf796ea5454be80c9eec2e8cfc73a15',1,'Qore.h']]],
  ['qore_5fmod_5fapi_5flist',['qore_mod_api_list',['../_module_manager_8h.html#ad50f255e8fa1555f632d314795c18ed0',1,'ModuleManager.h']]],
  ['qore_5fmod_5fapi_5flist_5flen',['qore_mod_api_list_len',['../_module_manager_8h.html#a741e33a9d4fa1c859221d28b7d08a614',1,'ModuleManager.h']]],
  ['qore_5fmodule_5fdir',['qore_module_dir',['../_qore_8h.html#ae2a979e14a7dc2fe6d90145af605b13b',1,'Qore.h']]],
  ['qore_5fmodule_5fver_5fdir',['qore_module_ver_dir',['../_qore_8h.html#a2b600359267eca2ad54892a1b1c64d68',1,'Qore.h']]],
  ['qore_5fmpfr_5finfo',['qore_mpfr_info',['../_qore_8h.html#ae605151efb26ed182db3e3ba17f7589e',1,'Qore.h']]],
  ['qore_5foption_5flist',['qore_option_list',['../_qore_lib_8h.html#a5cde9811a961ae6a74c0cd73475e57c4',1,'QoreLib.h']]],
  ['qore_5foption_5flist_5fsize',['qore_option_list_size',['../_qore_lib_8h.html#aa60708e218d814c21748ceea4cacf988',1,'QoreLib.h']]],
  ['qore_5ftarget_5farch',['qore_target_arch',['../_qore_8h.html#a5546e4dae74dad8cc82e5df8fad0b2ad',1,'Qore.h']]],
  ['qore_5ftarget_5fbits',['qore_target_bits',['../_qore_8h.html#a07892319abacd76008bc08af779fbd26',1,'Qore.h']]],
  ['qore_5ftarget_5fos',['qore_target_os',['../_qore_8h.html#a21698698cda36328f1e41b348c8cf369',1,'Qore.h']]],
  ['qore_5fuser_5fmodule_5fdir',['qore_user_module_dir',['../_qore_8h.html#a41fafaddbd9ab7c6b0ae0b4a96c15c5b',1,'Qore.h']]],
  ['qore_5fuser_5fmodule_5fver_5fdir',['qore_user_module_ver_dir',['../_qore_8h.html#a80830c640df29f1a70c152d2d579abaf',1,'Qore.h']]],
  ['qore_5fversion_5fmajor',['qore_version_major',['../_qore_8h.html#a52951fca864ecf13261713a95415a778',1,'Qore.h']]],
  ['qore_5fversion_5fminor',['qore_version_minor',['../_qore_8h.html#ae94a08dda726f7123de466ef8554feaa',1,'Qore.h']]],
  ['qore_5fversion_5fstring',['qore_version_string',['../_qore_8h.html#a8c83964eb36898516fa586eee168ec2d',1,'Qore.h']]],
  ['qore_5fversion_5fsub',['qore_version_sub',['../_qore_8h.html#acae8385e006320c7cea8b1ff11821440',1,'Qore.h']]],
  ['qorefeaturelist',['qoreFeatureList',['../_qore_lib_8h.html#a84f94f41c2e05181094a4d4b95359157',1,'QoreLib.h']]]
];
